@@ -12,20 +12,19 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-import struct
 import urlparse
 import os
 import pwd
 import grp
 import platform
 import logging
-import socket
 import json
-import fcntl
 import shutil
 import sys
 
 from OpenSSL import crypto
+from Crypto.PublicKey import RSA
+
 import netifaces
 import zmq.green as zmq
 import gevent
@@ -70,10 +69,9 @@ def drop_privileges(uid_name='nobody', gid_name='nogroup'):
 
 def create_self_signed_cert(cert_country, cert_state, cert_organization, cert_locality, cert_organizational_unit,
                             cert_common_name):
-    logger.info('Creating SSL Certificate and Key.')
-    pk = crypto.PKey()
-    pk.generate_key(crypto.TYPE_RSA, 1024)
-
+    logger.info('Creating certificate and key.')
+    rsa_key = RSA.generate(1024)
+    pk = crypto.load_privatekey(crypto.FILETYPE_PEM, rsa_key.exportKey('PEM', pkcs=1))
     cert = crypto.X509()
     sub = cert.get_subject()
     sub.CN = cert_common_name
@@ -94,7 +92,7 @@ def create_self_signed_cert(cert_country, cert_state, cert_organization, cert_lo
     cert.sign(pk, 'sha1')
 
     cert_text = crypto.dump_certificate(crypto.FILETYPE_PEM, cert)
-    priv_key_text = crypto.dump_privatekey(crypto.FILETYPE_PEM, pk)
+    priv_key_text = rsa_key.exportKey('PEM', pkcs=1)
 
     return cert_text, priv_key_text
 
